@@ -3,6 +3,5 @@ import os
 IFTTT_USERNAME = os.getenv('IFTTT_USERNAME')
 IFTTT_PASSWORD = os.getenv('IFTTT_PASSWORD')
 IFTTT_IMAP_SERVER = os.getenv('IFTTT_IMAP_SERVER')
-IFTTT_SMTP_SERVER = os.getenv('IFTTT_SMTP_SERVER')
 IFTTT_IMAP_PORT = os.getenv('IFTTT_IMAP_PORT', 993)
-IFTTT_SMTP_PORT = os.getenv('IFTTT_SMTP_PORT', 587)
+IFTTT_DELIM = os.getenv('IFTTT_DELIM', '\|\|\|\|\|')
\ No newline at end of file
